@@ -3,11 +3,15 @@ use Modern::Perl qw(2012);
 use Kavorka;
 use Types::Standard qw(ArrayRef Str);
 use Text::CSV::Slurp;
-use File::Slurp;
+use File::Slurp::Tiny 'write_file';
 use Exporter::Tidy all => [qw(exec_commands write_data)];
 use File::Temp qw(tempfile);
 use Carp::Assert;
 
+BEGIN {
+    system("which gnuplot") == 0 || die 'Gnuplot was not found from $PATH using which.';
+}
+
 #ABSTRACT   Gnuplot::Simple - A simple way to control Gnuplot
 
 =head1 NAME
@@ -23,7 +27,9 @@ to allow more convenient graph plotting from perl E.g.
 
   write_data("file.txt", [[ 1,2 ],[ 2,3 ]] );
 
-For obvious reasons, gnuplot needs to be installed for this module to work.
+For obvious reasons, gnuplot needs to be installed for this module to work. The presence
+of gnuplot is checked using the "which" shell command to verify that it is reachable
+via $PATH.
 
 =head1 FUNCTION/ATTRIBUTES
 
@@ -57,7 +63,7 @@ This software is licensed under the same terms as Perl itself.
 
 =cut
 
-fun _is_ascii ( Str $r) {
+fun _is_valid ( Str $r) {
     $r =~ /^[^\n\r"]*\z/;
 }
 
@@ -65,14 +71,14 @@ fun _check_constraint ( ArrayRef [ArrayRef] $data ) {
     die 'Non-empty data not accepted'
       unless @$data;
     for (@$data) {
-        assert _is_ascii( join "", @$_ ), "Non-ascii chars not allowed";
+        assert _is_valid( join "", @$_ ), '\n, \r or " chars not allowed in values.';
         assert @$_ > 0, "There must be more than one column";
     }
 }
 
 fun write_data ( Str $filename, $data ) {
     _check_constraint($data);
-    write_file( $filename, { binmode => ":utf8" }, _transform($data) );
+    write_file( $filename, _transform($data), binmode => ":utf8" );
 }
 
 fun _transform ( ArrayRef $data) {
